/* example-start gtkdial gtkdial.h */

/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GTK_DIAL_H__
#define __GTK_DIAL_H__


#include <gdk/gdk.h>
#include <gtk/gtkadjustment.h>
#include <gtk/gtkwidget.h>


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define GTK_DIAL(obj)          GTK_CHECK_CAST (obj, gtk_dial_get_type (), GtkDial)
#define GTK_DIAL_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gtk_dial_get_type (), GtkDialClass)
#define GTK_IS_DIAL(obj)       GTK_CHECK_TYPE (obj, gtk_dial_get_type ())


typedef struct _GtkDial        GtkDial;
typedef struct _GtkDialClass   GtkDialClass;

struct _GtkDial
{
  GtkWidget widget;

  /* update policy (GTK_UPDATE_[CONTINUOUS/DELAYED/DISCONTINUOUS]) */
  guint policy : 2;

  /* Button currently pressed or 0 if none */
  guint8 button;

  /* Dimensions of dial components */
  gint radius;
  gint pointer_width;

  /* ID of update timer, or 0 if none */
  guint32 timer;

  /* Current angle */
  gfloat angle;
  gfloat last_angle;

  /* Old values from adjustment stored so we know when something changes */
  gfloat old_value;
  gfloat old_lower;
  gfloat old_upper;

  /* The adjustment object that stores the data for this dial */
  GtkAdjustment *adjustment;
};

struct _GtkDialClass
{
  GtkWidgetClass parent_class;
};


GtkWidget*     gtk_dial_new                    (GtkAdjustment *adjustment);
guint          gtk_dial_get_type               (void);
GtkAdjustment* gtk_dial_get_adjustment         (GtkDial      *dial);
void           gtk_dial_set_update_policy      (GtkDial      *dial,
						GtkUpdateType  policy);

void           gtk_dial_set_adjustment         (GtkDial      *dial,
						GtkAdjustment *adjustment);
#ifdef __cplusplus
}
#endif /* __cplusplus */

#if defined(_CHDLL_) 
#include <dlfcn.h>
void *_ChGtkDial_handle = _dlopen("libgtkdial.dl", RTLD_LAZY);
if(_ChGtkDial_handle == NULL) {
   fprintf(_stderr, "Error: dlopen(): %s\n", dlerror());
   fprintf(_stderr, "       cannot get _ChGtkDial_handle in gtkdial.h\n");
   exit(-1);
} /* dlclose(_ChGtkDial_handle) will never be called */


GtkAdjustment* gtk_dial_get_adjustment(GtkDial *dial) {
    void *fptr;
    GtkAdjustment* retval;

    fptr = dlsym(_ChGtkDial_handle, "gtk_dial_get_adjustment_chdl");
    if(fptr == NULL) {
        fprintf(_stderr, "Error: %s(): dlsym(): %s\n", __func__,  dlerror());
        return NULL;
    }
    dlrunfun(fptr, &retval,gtk_dial_get_adjustment, dial);
    return retval;
}

guint gtk_dial_get_type() {
    void *fptr;
    guint retval;

    fptr = dlsym(_ChGtkDial_handle, "gtk_dial_get_type_chdl");
    if(fptr == NULL) {
        fprintf(_stderr, "Error: %s(): dlsym(): %s\n", __func__,  dlerror());
        return -1;
    }
    dlrunfun(fptr, &retval,gtk_dial_get_type);
    return retval;
}

GtkWidget* gtk_dial_new(GtkAdjustment *adjustment) {
    void *fptr;
    GtkWidget* retval;

    fptr = dlsym(_ChGtkDial_handle, "gtk_dial_new_chdl");
    if(fptr == NULL) {
        fprintf(_stderr, "Error: %s(): dlsym(): %s\n", __func__,  dlerror());
        return NULL;
    }
    dlrunfun(fptr, &retval,gtk_dial_new, adjustment);
    return retval;
}

void gtk_dial_set_adjustment(GtkDial *dial, GtkAdjustment *adjustment) {
    void *fptr;

    fptr = dlsym(_ChGtkDial_handle, "gtk_dial_set_adjustment_chdl");
    if(fptr == NULL) {
        fprintf(_stderr, "Error: %s(): dlsym(): %s\n", __func__,  dlerror());
    }
    dlrunfun(fptr, NULL, gtk_dial_set_adjustment, dial, adjustment);
}

void gtk_dial_set_update_policy(GtkDial *dial, GtkUpdateType policy) {
    void *fptr;

    fptr = dlsym(_ChGtkDial_handle, "gtk_dial_set_update_policy_chdl");
    if(fptr == NULL) {
        fprintf(_stderr, "Error: %s(): dlsym(): %s\n", __func__,  dlerror());
    }
    dlrunfun(fptr, NULL, gtk_dial_set_update_policy, dial, policy);
}

#endif

#endif /* __GTK_DIAL_H__ */
/* example-end */
